pub struct UpdateUserOptions {
pub role_uuid: Option<Option<Uuid>>,
pub external_id: Option<Option<CompactString>>,
pub username: Option<CompactString>,
pub email: Option<CompactString>,
pub name_first: Option<CompactString>,
pub name_last: Option<CompactString>,
pub password: Option<Option<CompactString>>,
pub toast_position: Option<UserToastPosition>,
pub start_on_grouped_servers: Option<bool>,
pub admin: Option<bool>,
pub language: Option<CompactString>,
}Fields
role_uuid: Option<Option<Uuid>>external_id: Option<Option<CompactString>>username: Option<CompactString>email: Option<CompactString>name_first: Option<CompactString>name_last: Option<CompactString>password: Option<Option<CompactString>>toast_position: Option<UserToastPosition>start_on_grouped_servers: Option<bool>admin: Option<bool>language: Option<CompactString>Trait Implementations
Sourceimpl ComposeSchema for UpdateUserOptions
impl ComposeSchema for UpdateUserOptions
Sourceimpl Default for UpdateUserOptions
impl Default for UpdateUserOptions
Sourcefn default() -> UpdateUserOptions
fn default() -> UpdateUserOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserOptions
impl<'de> Deserialize<'de> for UpdateUserOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateUserOptions
impl Serialize for UpdateUserOptions
Sourceimpl ToSchema for UpdateUserOptions
impl ToSchema for UpdateUserOptions
Sourceimpl Validate for UpdateUserOptions
impl Validate for UpdateUserOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateUserOptions
impl RefUnwindSafe for UpdateUserOptions
impl Send for UpdateUserOptions
impl Sync for UpdateUserOptions
impl Unpin for UpdateUserOptions
impl UnwindSafe for UpdateUserOptions