pub struct User {Show 23 fields
pub uuid: Uuid,
pub role: Option<Role>,
pub external_id: Option<CompactString>,
pub avatar: Option<String>,
pub username: CompactString,
pub email: CompactString,
pub name_first: Option<CompactString>,
pub name_last: Option<CompactString>,
pub admin: bool,
pub frozen: bool,
pub suspended: bool,
pub totp_enabled: bool,
pub totp_last_used: Option<NaiveDateTime>,
pub totp_secret: Option<String>,
pub email_two_factor_enabled: bool,
pub has_security_key: bool,
pub email_verified: bool,
pub password_login_disabled: bool,
pub language: CompactString,
pub toast_position: UserToastPosition,
pub start_on_grouped_servers: bool,
pub has_password: bool,
pub created: NaiveDateTime,
/* private fields */
}Fields
uuid: Uuidrole: Option<Role>external_id: Option<CompactString>avatar: Option<String>username: CompactStringemail: CompactStringname_first: Option<CompactString>name_last: Option<CompactString>admin: boolfrozen: boolsuspended: booltotp_enabled: booltotp_last_used: Option<NaiveDateTime>totp_secret: Option<String>email_two_factor_enabled: boolhas_security_key: boolemail_verified: boolpassword_login_disabled: boollanguage: CompactStringtoast_position: UserToastPositionstart_on_grouped_servers: boolhas_password: boolcreated: NaiveDateTimeImplementations
Sourceimpl User
impl User
Sourcepub async fn get_settings(
&self,
database: &Database,
) -> Result<UserSettings, Error>
pub async fn get_settings( &self, database: &Database, ) -> Result<UserSettings, Error>
Returns the settings of this user for reading.
Cached for 60 seconds, invalidated by UserSettingsMut::save.
Sourcepub async fn get_settings_mut(
&self,
database: &Database,
) -> Result<UserSettingsMut, Error>
pub async fn get_settings_mut( &self, database: &Database, ) -> Result<UserSettingsMut, Error>
Returns the settings of this user for modification, holding a lock that serializes
concurrent writers until the returned guard is dropped. Changes are only persisted
by UserSettingsMut::save.
Sourceimpl User
impl User
pub async fn create_automatic_admin( database: &Database, username: &str, email: &str, name_first: Option<&str>, name_last: Option<&str>, password: &str, ) -> Result<Uuid, DatabaseError>
pub async fn by_external_id( database: &Database, external_id: &str, ) -> Result<Option<Self>, DatabaseError>
Sourcepub async fn by_session_cached(
database: &Database,
session: &str,
) -> Result<Option<(Self, UserSession)>, Error>
pub async fn by_session_cached( database: &Database, session: &str, ) -> Result<Option<(Self, UserSession)>, Error>
Returns the user and session associated with the given session string, if valid.
Cached for 5 seconds.
Sourcepub async fn by_api_key_cached(
database: &Database,
key: &str,
) -> Result<Option<(Self, UserApiKey)>, Error>
pub async fn by_api_key_cached( database: &Database, key: &str, ) -> Result<Option<(Self, UserApiKey)>, Error>
Returns the user and API key associated with the given API key string, if valid.
Cached for 5 seconds.
pub async fn by_credential_id( database: &Database, credential_id: &CredentialID, ) -> Result<Option<(Self, UserSecurityKey)>, DatabaseError>
pub async fn by_email( database: &Database, email: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_email_password( database: &Database, email: &str, password: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username( database: &Database, username: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username_password( database: &Database, username: &str, password: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username_public_key( database: &Database, username: &str, public_key: PublicKey, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_role_uuid_with_pagination( database: &Database, role_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn all_with_pagination( database: &Database, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn count(database: &Database) -> i64
pub async fn validate_password( &self, database: &Database, password: &str, ) -> Result<bool, DatabaseError>
Sourcepub async fn update_password(
&mut self,
database: &Database,
password: Option<&str>,
) -> Result<(), DatabaseError>
pub async fn update_password( &mut self, database: &Database, password: Option<&str>, ) -> Result<(), DatabaseError>
Update the User password, None will disallow password login and not require one when changing
Sourcepub async fn update_password_with_transaction(
&mut self,
transaction: &mut Transaction<'_, Postgres>,
password: Option<&str>,
) -> Result<(), DatabaseError>
pub async fn update_password_with_transaction( &mut self, transaction: &mut Transaction<'_, Postgres>, password: Option<&str>, ) -> Result<(), DatabaseError>
Update the User password, None will disallow password login and not require one when changing
pub fn require_two_factor(&self, settings: &AppSettings) -> bool
pub fn has_two_factor_method( &self, method: TwoFactorMethod, settings: &AppSettings, ) -> bool
Sourcepub fn two_factor_methods(&self, settings: &AppSettings) -> Vec<TwoFactorMethod>
pub fn two_factor_methods(&self, settings: &AppSettings) -> Vec<TwoFactorMethod>
Every factor the user has, regardless of whether an admin counts it towards the requirement.
pub fn satisfies_two_factor(&self, settings: &AppSettings) -> bool
pub fn require_email_verification(&self, settings: &AppSettings) -> bool
pub async fn into_api_full_object( self, state: &State, storage_url_retriever: &StorageUrlRetriever<'_>, ) -> Result<ApiFullUser, DatabaseError>