pub struct User {Show 17 fields
pub uuid: Uuid,
pub role: Option<Role>,
pub external_id: Option<CompactString>,
pub avatar: Option<String>,
pub username: CompactString,
pub email: CompactString,
pub name_first: CompactString,
pub name_last: CompactString,
pub admin: bool,
pub totp_enabled: bool,
pub totp_last_used: Option<NaiveDateTime>,
pub totp_secret: Option<String>,
pub language: CompactString,
pub toast_position: UserToastPosition,
pub start_on_grouped_servers: bool,
pub has_password: bool,
pub created: NaiveDateTime,
}Fields
uuid: Uuidrole: Option<Role>external_id: Option<CompactString>avatar: Option<String>username: CompactStringemail: CompactStringname_first: CompactStringname_last: CompactStringadmin: booltotp_enabled: booltotp_last_used: Option<NaiveDateTime>totp_secret: Option<String>language: CompactStringtoast_position: UserToastPositionstart_on_grouped_servers: boolhas_password: boolcreated: NaiveDateTimeImplementations
Sourceimpl User
impl User
pub async fn create_automatic_admin( database: &Database, username: &str, email: &str, name_first: &str, name_last: &str, password: &str, ) -> Result<Uuid, DatabaseError>
pub async fn by_external_id( database: &Database, external_id: &str, ) -> Result<Option<Self>, DatabaseError>
Sourcepub async fn by_session_cached(
database: &Database,
session: &str,
) -> Result<Option<(Self, UserSession)>, Error>
pub async fn by_session_cached( database: &Database, session: &str, ) -> Result<Option<(Self, UserSession)>, Error>
Returns the user and session associated with the given session string, if valid.
Cached for 5 seconds.
Sourcepub async fn by_api_key_cached(
database: &Database,
key: &str,
) -> Result<Option<(Self, UserApiKey)>, Error>
pub async fn by_api_key_cached( database: &Database, key: &str, ) -> Result<Option<(Self, UserApiKey)>, Error>
Returns the user and API key associated with the given API key string, if valid.
Cached for 5 seconds.
pub async fn by_credential_id( database: &Database, credential_id: &CredentialID, ) -> Result<Option<(Self, UserSecurityKey)>, DatabaseError>
pub async fn by_email( database: &Database, email: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_email_password( database: &Database, email: &str, password: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username( database: &Database, username: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username_password( database: &Database, username: &str, password: &str, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_username_public_key( database: &Database, username: &str, public_key: PublicKey, ) -> Result<Option<Self>, DatabaseError>
pub async fn by_role_uuid_with_pagination( database: &Database, role_uuid: Uuid, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn all_with_pagination( database: &Database, page: i64, per_page: i64, search: Option<&str>, ) -> Result<Pagination<Self>, DatabaseError>
pub async fn count(database: &Database) -> i64
pub async fn validate_password( &self, database: &Database, password: &str, ) -> Result<bool, DatabaseError>
Sourcepub async fn update_password(
&mut self,
database: &Database,
password: Option<&str>,
) -> Result<(), DatabaseError>
pub async fn update_password( &mut self, database: &Database, password: Option<&str>, ) -> Result<(), DatabaseError>
Update the User password, None will disallow password login and not require one when changing
pub fn require_two_factor(&self, settings: &AppSettings) -> bool
pub fn into_api_object( self, storage_url_retriever: &StorageUrlRetriever<'_>, ) -> ApiUser
pub fn into_api_full_object( self, storage_url_retriever: &StorageUrlRetriever<'_>, ) -> ApiFullUser